summaryrefslogtreecommitdiff
path: root/test/integration/nickserver_test.rb
diff options
context:
space:
mode:
authorAzul <azul@riseup.net>2016-06-30 11:23:45 +0200
committerAzul <azul@riseup.net>2016-06-30 12:04:07 +0200
commit0491e79c4e5f16d38cf87e53290394e1eccfa2e9 (patch)
tree56d0aff1fc8ca1bbd11b09bc6929f00132467898 /test/integration/nickserver_test.rb
parent4132d6e6db3755334ace352165991487802c6b82 (diff)
Trying to replace EM base server with reel
some tests are still broken. But at least they are running now.
Diffstat (limited to 'test/integration/nickserver_test.rb')
-rw-r--r--test/integration/nickserver_test.rb80
1 files changed, 31 insertions, 49 deletions
diff --git a/test/integration/nickserver_test.rb b/test/integration/nickserver_test.rb
index b4ff4da..00b2642 100644
--- a/test/integration/nickserver_test.rb
+++ b/test/integration/nickserver_test.rb
@@ -1,21 +1,27 @@
require 'test_helper'
require 'json'
+require 'celluloid/test'
#
# Some important notes to understanding these tests:
#
# (1) Requests to localhost always bypass HTTP stub.
#
# (2) All requests to nickserver are to localhost.
#
# (3) the "Host" header for requests to nickserver must be set (or Config.domain set)
#
# (4) When stubbing requests to couchdb, the couchdb host is changed from the
# default (localhost) to a dummy value (notlocalhost).
#
class NickserverTest < Minitest::Test
+ def setup
+ super
+ Celluloid.shutdown; Celluloid.boot
+ end
+
def test_GET_served_via_SKS
uid = 'cloudadmin@leap.se'
key_id = 'E818C478D3141282F7590D29D041EB11B1647490'
@@ -24,9 +30,8 @@ class NickserverTest < Minitest::Test
start do
params = {query: {"address" => uid}}
- get(params) do |http|
- assert_equal file_content(:leap_public_key), JSON.parse(http.response)["openpgp"]
- stop
+ get(params) do |response|
+ assert_equal file_content(:leap_public_key), JSON.parse(response.to_s)["openpgp"]
end
end
end
@@ -39,9 +44,8 @@ class NickserverTest < Minitest::Test
start do
params = {body: {"address" => uid}}
- post(params) do |http|
- assert_equal file_content(:leap_public_key), JSON.parse(http.response)["openpgp"]
- stop
+ post(params) do |response|
+ assert_equal file_content(:leap_public_key), JSON.parse(response.to_s)["openpgp"]
end
end
end
@@ -52,9 +56,8 @@ class NickserverTest < Minitest::Test
stub_couch_response(uid, status: 404) do
start do
params = {query: {"address" => uid}, head: {host: domain}}
- get(params) do |http|
- assert_equal 404, http.response_header.status
- stop
+ get(params) do |response|
+ assert_equal 404, response.code
end
end
end
@@ -66,9 +69,8 @@ class NickserverTest < Minitest::Test
stub_couch_response(uid, body: file_content(:empty_couchdb_result)) do
start do
params = {query: {"address" => uid}, head: {host: domain}}
- get(params) do |http|
- assert_equal 404, http.response_header.status
- stop
+ get(params) do |response|
+ assert_equal 404, response.code
end
end
end
@@ -80,9 +82,8 @@ class NickserverTest < Minitest::Test
stub_couch_response(uid, body: file_content(:blue_couchdb_result)) do
start do
params = {query: {"address" => uid}, head: {host: domain}}
- get(params) do |http|
- assert_equal file_content(:blue_nickserver_result), http.response
- stop
+ get(params) do |response|
+ assert_equal file_content(:blue_nickserver_result), response.to_s
end
end
end
@@ -90,9 +91,8 @@ class NickserverTest < Minitest::Test
def test_GET_empty
start do
- get({}) do |http|
- assert_equal "404 Not Found\n", http.response
- stop
+ get({}) do |response|
+ assert_equal "404 Not Found\n", response.to_s
end
end
end
@@ -103,53 +103,35 @@ class NickserverTest < Minitest::Test
# start nickserver
#
def start(timeout = 1)
- Timeout::timeout(timeout) do
- EM.run do
- Nickserver::Server.start
- EM.epoll
- yield
- end
- end
- rescue Timeout::Error
- flunk 'EventMachine was not stopped before the timeout expired'
+ server = Nickserver::ReelServer.new '127.0.0.1', config.port
+ yield server
+ ensure
+ server.terminate if server && server.alive?
end
#
# http GET requests to nickserver
#
def get(params, &block)
- request(:get, params, &block)
+ request(:get, params[:query], &block)
end
#
# http POST requests to nickserver
#
def post(params, &block)
- request(:post, params, &block)
+ request(:post, params[:body], &block)
end
#
# http request to nickserver
#
# this works because http requests to localhost are not stubbed, but requests to other domains are.
#
def request(method, params)
- EventMachine::HttpRequest.new("http://localhost:#{Nickserver::Config.port}/").send(method,params).callback {|http|
- # p http.response_header.status
- # p http.response_header
- # p http.response
- yield http
- }.errback {|http|
- flunk(http.error) if http.error
- EM.stop
- }
- end
-
- #
- # stop nickserver
- #
- def stop
- EM.stop
+ request = HTTP.request method, "http://127.0.0.1:#{config.port}/",
+ params: params
+ yield request
end
end
@@ -1,21 +1,27 @@
# Some important notes to understanding these tests:
#
-# (1) Requests to localhost always bypass HTTP stub.
+# (1) Requests to 127.0.0.1 always bypass HTTP stub.
#
@@ -1,21 +1,27 @@
#
-# (2) All requests to nickserver are to localhost.
+# (2) All requests to nickserver are to 127.0.0.1.
#
# (3) the "Host" header for requests to nickserver must be set (or Config.domain set)
@@ -1,21 +1,27 @@
#
# (4) When stubbing requests to couchdb, the couchdb host is changed from the
-# default (localhost) to a dummy value (notlocalhost).
+# default (127.0.0.1) to a dummy value (notlocalhost).
#
class NickserverTest < Minitest::Test
@@ -103,53 +103,35 @@ class NickserverTest < Minitest::Test
# http request to nickserver
#
- # this works because http requests to localhost are not stubbed, but requests to other domains are.
+ # this works because http requests to 127.0.0.1 are not stubbed, but requests to other domains are.
#
def request(method, params)